@@ -72,12 +72,11 @@ def test_load_yaml_configuration():  # noqa: D103
     filename = local_path / "tests" / "config" / "test.yaml"
 
     manager.load_yaml_configuration(filename=filename)
-    local_temp_path = manager.local_temp_path
 
     manager.initialise_data_sources()
-    assert len(manager.data_sources) == 7
+    assert len(manager.data_sources) == 8
     assert isinstance(manager.data_source_which_defines_geospatial_locations, GSPDataSource)
-    assert isinstance(local_temp_path, Path)
+    assert isinstance(manager.config.process.local_temp_path, Path)
 
 
 def test_get_daylight_datetime_index():
@@ -110,42 +109,6 @@ def test_get_daylight_datetime_index():
 
 def test_batches():
     """Test that batches can be made"""
-    filename = Path(nowcasting_dataset.__file__).parent.parent / "tests" / "data" / "sat_data.zarr"
-
-    sat = SatelliteDataSource(
-        zarr_path=filename,
-        history_minutes=30,
-        forecast_minutes=60,
-        image_size_pixels=24,
-        meters_per_pixel=6000,
-        channels=("IR_016",),
-    )
-
-    filename = (
-        Path(nowcasting_dataset.__file__).parent.parent / "tests" / "data" / "hrv_sat_data.zarr"
-    )
-    hrvsat = SatelliteDataSource(
-        zarr_path=filename,
-        history_minutes=30,
-        forecast_minutes=60,
-        image_size_pixels=64,
-        meters_per_pixel=2000,
-        channels=("HRV",),
-    )
-
-    filename = (
-        Path(nowcasting_dataset.__file__).parent.parent / "tests" / "data" / "gsp" / "test.zarr"
-    )
-
-    gsp = GSPDataSource(
-        zarr_path=filename,
-        start_datetime=datetime(2020, 4, 1),
-        end_datetime=datetime(2020, 4, 2),
-        history_minutes=30,
-        forecast_minutes=60,
-        image_size_pixels=64,
-        meters_per_pixel=2000,
-    )
 
     manager = Manager()
 
@@ -160,8 +123,51 @@ def test_batches():
         manager.config.output_data.filepath = Path(dst_path)
         manager.local_temp_path = Path(local_temp_path)
 
+        # set up loggers
+        manager.configure_loggers(log_level="DEBUG")
+
         # just set satellite as data source
-        manager.data_sources = {"gsp": gsp, "sat": sat, "hrvsat": hrvsat}
+        filename = (
+            Path(nowcasting_dataset.__file__).parent.parent / "tests" / "data" / "sat_data.zarr"
+        )
+
+        sat = SatelliteDataSource(
+            zarr_path=filename,
+            history_minutes=30,
+            forecast_minutes=60,
+            image_size_pixels=24,
+            meters_per_pixel=6000,
+            channels=("IR_016",),
+        )
+
+        filename = (
+            Path(nowcasting_dataset.__file__).parent.parent / "tests" / "data" / "hrv_sat_data.zarr"
+        )
+        hrvsat = SatelliteDataSource(
+            zarr_path=filename,
+            history_minutes=30,
+            forecast_minutes=60,
+            image_size_pixels=64,
+            meters_per_pixel=2000,
+            channels=("HRV",),
+        )
+
+        filename = (
+            Path(nowcasting_dataset.__file__).parent.parent / "tests" / "data" / "gsp" / "test.zarr"
+        )
+
+        gsp = GSPDataSource(
+            zarr_path=filename,
+            start_datetime=datetime(2020, 4, 1),
+            end_datetime=datetime(2020, 4, 2),
+            history_minutes=30,
+            forecast_minutes=60,
+            image_size_pixels=64,
+            meters_per_pixel=2000,
+        )
+
+        # Set data sources
+        manager.data_sources = {"gsp": gsp, "satellite": sat, "hrvsatellite": hrvsat}
         manager.data_source_which_defines_geospatial_locations = gsp
 
         # make file for locations
@@ -173,11 +179,20 @@ def test_batches():
         assert os.path.exists(f"{dst_path}/train")
         assert os.path.exists(f"{dst_path}/train/gsp")
         assert os.path.exists(f"{dst_path}/train/gsp/000000.nc")
-        assert os.path.exists(f"{dst_path}/train/sat/000000.nc")
         assert os.path.exists(f"{dst_path}/train/gsp/000001.nc")
-        assert os.path.exists(f"{dst_path}/train/sat/000001.nc")
-        assert os.path.exists(f"{dst_path}/train/hrvsat/000001.nc")
-        assert os.path.exists(f"{dst_path}/train/hrvsat/000000.nc")
+        assert os.path.exists(f"{dst_path}/train/satellite/000000.nc")
+        assert os.path.exists(f"{dst_path}/train/satellite/000001.nc")
+        assert os.path.exists(f"{dst_path}/train/hrvsatellite/000001.nc")
+        assert os.path.exists(f"{dst_path}/train/hrvsatellite/000000.nc")
+
+        # check logs is appended to
+        for log_file in ["combined", "gsp", "satellite"]:
+            filename = f"{dst_path}/{log_file}.log"
+            assert os.path.exists(filename)
+            with open(filename) as f:
+                num_lines = sum(1 for line in f)
+                print(num_lines, log_file)
+                assert num_lines > 0, f"Log {filename} is empty"
 
 
 def test_save_config():
